"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const react = require("@graphiql/react");
const React = require("react");
const majorVersion = parseInt(React.version.slice(0, 2), 10);
if (majorVersion < 16) {
  throw new Error(
    [
      "GraphiQL 0.18.0 and after is not compatible with React 15 or below.",
      "If you are using a CDN source (jsdelivr, unpkg, etc), follow this example:",
      "https://github.com/graphql/graphiql/blob/master/examples/graphiql-cdn/index.html#L49"
    ].join("\n")
  );
}
function GraphiQL({
  dangerouslyAssumeSchemaIsValid,
  defaultQuery,
  defaultTabs,
  externalFragments,
  fetcher,
  getDefaultFieldNames,
  headers,
  inputValueDeprecation,
  introspectionQueryName,
  maxHistoryLength,
  onEditOperationName,
  onSchemaChange,
  onTabChange,
  onTogglePluginVisibility,
  operationName,
  plugins,
  query,
  response,
  schema,
  schemaDescription,
  shouldPersistHeaders,
  storage,
  validationRules,
  variables,
  visiblePlugin,
  defaultHeaders,
  ...props
}) {
  if (typeof fetcher !== "function") {
    throw new TypeError(
      "The `GraphiQL` component requires a `fetcher` function to be passed as prop."
    );
  }
  return /* @__PURE__ */ React.createElement(
    react.GraphiQLProvider,
    {
      getDefaultFieldNames,
      dangerouslyAssumeSchemaIsValid,
      defaultQuery,
      defaultHeaders,
      defaultTabs,
      externalFragments,
      fetcher,
      headers,
      inputValueDeprecation,
      introspectionQueryName,
      maxHistoryLength,
      onEditOperationName,
      onSchemaChange,
      onTabChange,
      onTogglePluginVisibility,
      plugins,
      visiblePlugin,
      operationName,
      query,
      response,
      schema,
      schemaDescription,
      shouldPersistHeaders,
      storage,
      validationRules,
      variables
    },
    /* @__PURE__ */ React.createElement(
      GraphiQLInterface,
      {
        showPersistHeadersSettings: shouldPersistHeaders !== false,
        forcedTheme: props.forcedTheme,
        ...props
      }
    )
  );
}
GraphiQL.Logo = GraphiQLLogo;
GraphiQL.Toolbar = GraphiQLToolbar;
GraphiQL.Footer = GraphiQLFooter;
const THEMES = ["light", "dark", "system"];
function GraphiQLInterface(props) {
  var _a, _b, _c;
  const isHeadersEditorEnabled = props.isHeadersEditorEnabled ?? true;
  const editorContext = react.useEditorContext({ nonNull: true });
  const executionContext = react.useExecutionContext({ nonNull: true });
  const schemaContext = react.useSchemaContext({ nonNull: true });
  const storageContext = react.useStorageContext();
  const pluginContext = react.usePluginContext();
  const forcedTheme = React.useMemo(
    () => props.forcedTheme && THEMES.includes(props.forcedTheme) ? props.forcedTheme : void 0,
    [props.forcedTheme]
  );
  const copy = react.useCopyQuery({ onCopyQuery: props.onCopyQuery });
  const merge = react.useMergeQuery();
  const prettify = react.usePrettifyEditors();
  const { theme, setTheme } = react.useTheme();
  React.useEffect(() => {
    if (forcedTheme === "system") {
      setTheme(null);
    } else if (forcedTheme === "light" || forcedTheme === "dark") {
      setTheme(forcedTheme);
    }
  }, [forcedTheme, setTheme]);
  const PluginContent = (_a = pluginContext == null ? void 0 : pluginContext.visiblePlugin) == null ? void 0 : _a.content;
  const pluginResize = react.useDragResize({
    defaultSizeRelation: 1 / 3,
    direction: "horizontal",
    initiallyHidden: (pluginContext == null ? void 0 : pluginContext.visiblePlugin) ? void 0 : "first",
    onHiddenElementChange(resizableElement) {
      if (resizableElement === "first") {
        pluginContext == null ? void 0 : pluginContext.setVisiblePlugin(null);
      }
    },
    sizeThresholdSecond: 200,
    storageKey: "docExplorerFlex"
  });
  const editorResize = react.useDragResize({
    direction: "horizontal",
    storageKey: "editorFlex"
  });
  const editorToolsResize = react.useDragResize({
    defaultSizeRelation: 3,
    direction: "vertical",
    initiallyHidden: (() => {
      if (props.defaultEditorToolsVisibility === "variables" || props.defaultEditorToolsVisibility === "headers") {
        return;
      }
      if (typeof props.defaultEditorToolsVisibility === "boolean") {
        return props.defaultEditorToolsVisibility ? void 0 : "second";
      }
      return editorContext.initialVariables || editorContext.initialHeaders ? void 0 : "second";
    })(),
    sizeThresholdSecond: 60,
    storageKey: "secondaryEditorFlex"
  });
  const [activeSecondaryEditor, setActiveSecondaryEditor] = React.useState(() => {
    if (props.defaultEditorToolsVisibility === "variables" || props.defaultEditorToolsVisibility === "headers") {
      return props.defaultEditorToolsVisibility;
    }
    return !editorContext.initialVariables && editorContext.initialHeaders && isHeadersEditorEnabled ? "headers" : "variables";
  });
  const [showDialog, setShowDialog] = React.useState(null);
  const [clearStorageStatus, setClearStorageStatus] = React.useState(null);
  const children = React.Children.toArray(props.children);
  const logo = children.find(
    (child) => isChildComponentType(child, GraphiQL.Logo)
  ) || /* @__PURE__ */ React.createElement(GraphiQL.Logo, null);
  const toolbar = children.find(
    (child) => isChildComponentType(child, GraphiQL.Toolbar)
  ) || /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(react.ToolbarButton, { onClick: prettify, label: "Prettify query (Shift-Ctrl-P)" }, /* @__PURE__ */ React.createElement(react.PrettifyIcon, { className: "graphiql-toolbar-icon", "aria-hidden": "true" })), /* @__PURE__ */ React.createElement(
    react.ToolbarButton,
    {
      onClick: merge,
      label: "Merge fragments into query (Shift-Ctrl-M)"
    },
    /* @__PURE__ */ React.createElement(react.MergeIcon, { className: "graphiql-toolbar-icon", "aria-hidden": "true" })
  ), /* @__PURE__ */ React.createElement(react.ToolbarButton, { onClick: copy, label: "Copy query (Shift-Ctrl-C)" }, /* @__PURE__ */ React.createElement(react.CopyIcon, { className: "graphiql-toolbar-icon", "aria-hidden": "true" })), (_b = props.toolbar) == null ? void 0 : _b.additionalContent, ((_c = props.toolbar) == null ? void 0 : _c.additionalComponent) && /* @__PURE__ */ React.createElement(props.toolbar.additionalComponent, null));
  const footer = children.find(
    (child) => isChildComponentType(child, GraphiQL.Footer)
  );
  const onClickReference = React.useCallback(() => {
    if (pluginResize.hiddenElement === "first") {
      pluginResize.setHiddenElement(null);
    }
  }, [pluginResize]);
  const handleClearData = React.useCallback(() => {
    try {
      storageContext == null ? void 0 : storageContext.clear();
      setClearStorageStatus("success");
    } catch {
      setClearStorageStatus("error");
    }
  }, [storageContext]);
  const handlePersistHeaders = React.useCallback(
    (event) => {
      editorContext.setShouldPersistHeaders(
        event.currentTarget.dataset.value === "true"
      );
    },
    [editorContext]
  );
  const handleChangeTheme = React.useCallback(
    (event) => {
      const selectedTheme = event.currentTarget.dataset.theme;
      setTheme(selectedTheme || null);
    },
    [setTheme]
  );
  const handleAddTab = editorContext.addTab;
  const handleRefetchSchema = schemaContext.introspect;
  const handleReorder = editorContext.moveTab;
  const handleShowDialog = React.useCallback(
    (event) => {
      setShowDialog(
        event.currentTarget.dataset.value
      );
    },
    []
  );
  const handlePluginClick = React.useCallback(
    (e) => {
      const context = pluginContext;
      const pluginIndex = Number(e.currentTarget.dataset.index);
      const plugin = context.plugins.find((_, index) => pluginIndex === index);
      const isVisible = plugin === context.visiblePlugin;
      if (isVisible) {
        context.setVisiblePlugin(null);
        pluginResize.setHiddenElement("first");
      } else {
        context.setVisiblePlugin(plugin);
        pluginResize.setHiddenElement(null);
      }
    },
    [pluginContext, pluginResize]
  );
  const handleToolsTabClick = React.useCallback(
    (event) => {
      if (editorToolsResize.hiddenElement === "second") {
        editorToolsResize.setHiddenElement(null);
      }
      setActiveSecondaryEditor(
        event.currentTarget.dataset.name
      );
    },
    [editorToolsResize]
  );
  const toggleEditorTools = React.useCallback(() => {
    editorToolsResize.setHiddenElement(
      editorToolsResize.hiddenElement === "second" ? null : "second"
    );
  }, [editorToolsResize]);
  const handleOpenShortKeysDialog = React.useCallback((isOpen) => {
    if (!isOpen) {
      setShowDialog(null);
    }
  }, []);
  const handleOpenSettingsDialog = React.useCallback((isOpen) => {
    if (!isOpen) {
      setShowDialog(null);
      setClearStorageStatus(null);
    }
  }, []);
  const hasMultipleTabs = editorContext.tabs.length > 1;
  const className = props.className ? ` ${props.className}` : "";
  return /* @__PURE__ */ React.createElement(react.Tooltip.Provider, null, /* @__PURE__ */ React.createElement("div", { className: `graphiql-container${className}` }, /* @__PURE__ */ React.createElement("div", { className: "graphiql-sidebar" }, /* @__PURE__ */ React.createElement("div", { className: "graphiql-sidebar-section" }, pluginContext == null ? void 0 : pluginContext.plugins.map((plugin, index) => {
    const isVisible = plugin === pluginContext.visiblePlugin;
    const label = `${isVisible ? "Hide" : "Show"} ${plugin.title}`;
    const Icon = plugin.icon;
    return /* @__PURE__ */ React.createElement(react.Tooltip, { key: plugin.title, label }, /* @__PURE__ */ React.createElement(
      react.UnStyledButton,
      {
        type: "button",
        className: isVisible ? "active" : "",
        onClick: handlePluginClick,
        "data-index": index,
        "aria-label": label
      },
      /* @__PURE__ */ React.createElement(Icon, { "aria-hidden": "true" })
    ));
  })), /* @__PURE__ */ React.createElement("div", { className: "graphiql-sidebar-section" }, /* @__PURE__ */ React.createElement(react.Tooltip, { label: "Re-fetch GraphQL schema" }, /* @__PURE__ */ React.createElement(
    react.UnStyledButton,
    {
      type: "button",
      disabled: schemaContext.isFetching,
      onClick: handleRefetchSchema,
      "aria-label": "Re-fetch GraphQL schema"
    },
    /* @__PURE__ */ React.createElement(
      react.ReloadIcon,
      {
        className: schemaContext.isFetching ? "graphiql-spin" : "",
        "aria-hidden": "true"
      }
    )
  )), /* @__PURE__ */ React.createElement(react.Tooltip, { label: "Open short keys dialog" }, /* @__PURE__ */ React.createElement(
    react.UnStyledButton,
    {
      type: "button",
      "data-value": "short-keys",
      onClick: handleShowDialog,
      "aria-label": "Open short keys dialog"
    },
    /* @__PURE__ */ React.createElement(react.KeyboardShortcutIcon, { "aria-hidden": "true" })
  )), /* @__PURE__ */ React.createElement(react.Tooltip, { label: "Open settings dialog" }, /* @__PURE__ */ React.createElement(
    react.UnStyledButton,
    {
      type: "button",
      "data-value": "settings",
      onClick: handleShowDialog,
      "aria-label": "Open settings dialog"
    },
    /* @__PURE__ */ React.createElement(react.SettingsIcon, { "aria-hidden": "true" })
  )))), /* @__PURE__ */ React.createElement("div", { className: "graphiql-main" }, /* @__PURE__ */ React.createElement(
    "div",
    {
      ref: pluginResize.firstRef,
      style: {
        // Make sure the container shrinks when containing long
        // non-breaking texts
        minWidth: "200px"
      }
    },
    /* @__PURE__ */ React.createElement("div", { className: "graphiql-plugin" }, PluginContent ? /* @__PURE__ */ React.createElement(PluginContent, null) : null)
  ), (pluginContext == null ? void 0 : pluginContext.visiblePlugin) && /* @__PURE__ */ React.createElement(
    "div",
    {
      className: "graphiql-horizontal-drag-bar",
      ref: pluginResize.dragBarRef
    }
  ), /* @__PURE__ */ React.createElement("div", { ref: pluginResize.secondRef, className: "graphiql-sessions" }, /* @__PURE__ */ React.createElement("div", { className: "graphiql-session-header" }, hasMultipleTabs && /* @__PURE__ */ React.createElement(
    react.Tabs,
    {
      values: editorContext.tabs,
      onReorder: handleReorder,
      "aria-label": "Select active operation"
    },
    editorContext.tabs.map((tab, index) => /* @__PURE__ */ React.createElement(react.Tooltip, { key: tab.id, label: tab.title }, /* @__PURE__ */ React.createElement(
      react.Tab,
      {
        value: tab,
        isActive: index === editorContext.activeTabIndex
      },
      /* @__PURE__ */ React.createElement(
        react.Tab.Button,
        {
          "aria-controls": "graphiql-session",
          id: `graphiql-session-tab-${index}`,
          onClick: () => {
            executionContext.stop();
            editorContext.changeTab(index);
          }
        },
        tab.title
      ),
      /* @__PURE__ */ React.createElement(
        react.Tab.Close,
        {
          onClick: () => {
            if (editorContext.activeTabIndex === index) {
              executionContext.stop();
            }
            editorContext.closeTab(index);
          }
        }
      )
    )))
  ), /* @__PURE__ */ React.createElement(react.Tooltip, { label: "New tab" }, /* @__PURE__ */ React.createElement(
    react.UnStyledButton,
    {
      type: "button",
      className: "graphiql-tab-add",
      onClick: handleAddTab,
      "aria-label": "New tab"
    },
    /* @__PURE__ */ React.createElement(react.PlusIcon, { "aria-hidden": "true" })
  )), logo), /* @__PURE__ */ React.createElement(
    "div",
    {
      role: "tabpanel",
      id: "graphiql-session",
      className: "graphiql-session",
      "aria-labelledby": `graphiql-session-tab-${editorContext.activeTabIndex}`
    },
    /* @__PURE__ */ React.createElement("div", { ref: editorResize.firstRef }, /* @__PURE__ */ React.createElement(
      "div",
      {
        className: "graphiql-editors",
        style: hasMultipleTabs ? { borderTopLeftRadius: 0, borderTopRightRadius: 0 } : {
          marginTop: "calc(var(--px-8) - var(--session-header-height))"
        }
      },
      /* @__PURE__ */ React.createElement("div", { ref: editorToolsResize.firstRef }, /* @__PURE__ */ React.createElement(
        "section",
        {
          className: "graphiql-query-editor",
          "aria-label": "Query Editor"
        },
        /* @__PURE__ */ React.createElement(
          react.QueryEditor,
          {
            editorTheme: props.editorTheme,
            keyMap: props.keyMap,
            onClickReference,
            onCopyQuery: props.onCopyQuery,
            onEdit: props.onEditQuery,
            readOnly: props.readOnly
          }
        ),
        /* @__PURE__ */ React.createElement(
          "div",
          {
            className: "graphiql-toolbar",
            role: "toolbar",
            "aria-label": "Editor Commands"
          },
          /* @__PURE__ */ React.createElement(react.ExecuteButton, null),
          toolbar
        )
      )),
      /* @__PURE__ */ React.createElement("div", { ref: editorToolsResize.dragBarRef }, /* @__PURE__ */ React.createElement("div", { className: "graphiql-editor-tools" }, /* @__PURE__ */ React.createElement(
        react.UnStyledButton,
        {
          type: "button",
          className: activeSecondaryEditor === "variables" && editorToolsResize.hiddenElement !== "second" ? "active" : "",
          onClick: handleToolsTabClick,
          "data-name": "variables"
        },
        "Variables"
      ), isHeadersEditorEnabled && /* @__PURE__ */ React.createElement(
        react.UnStyledButton,
        {
          type: "button",
          className: activeSecondaryEditor === "headers" && editorToolsResize.hiddenElement !== "second" ? "active" : "",
          onClick: handleToolsTabClick,
          "data-name": "headers"
        },
        "Headers"
      ), /* @__PURE__ */ React.createElement(
        react.Tooltip,
        {
          label: editorToolsResize.hiddenElement === "second" ? "Show editor tools" : "Hide editor tools"
        },
        /* @__PURE__ */ React.createElement(
          react.UnStyledButton,
          {
            type: "button",
            onClick: toggleEditorTools,
            "aria-label": editorToolsResize.hiddenElement === "second" ? "Show editor tools" : "Hide editor tools",
            className: "graphiql-toggle-editor-tools"
          },
          editorToolsResize.hiddenElement === "second" ? /* @__PURE__ */ React.createElement(
            react.ChevronUpIcon,
            {
              className: "graphiql-chevron-icon",
              "aria-hidden": "true"
            }
          ) : /* @__PURE__ */ React.createElement(
            react.ChevronDownIcon,
            {
              className: "graphiql-chevron-icon",
              "aria-hidden": "true"
            }
          )
        )
      ))),
      /* @__PURE__ */ React.createElement("div", { ref: editorToolsResize.secondRef }, /* @__PURE__ */ React.createElement(
        "section",
        {
          className: "graphiql-editor-tool",
          "aria-label": activeSecondaryEditor === "variables" ? "Variables" : "Headers"
        },
        /* @__PURE__ */ React.createElement(
          react.VariableEditor,
          {
            editorTheme: props.editorTheme,
            isHidden: activeSecondaryEditor !== "variables",
            keyMap: props.keyMap,
            onEdit: props.onEditVariables,
            onClickReference,
            readOnly: props.readOnly
          }
        ),
        isHeadersEditorEnabled && /* @__PURE__ */ React.createElement(
          react.HeaderEditor,
          {
            editorTheme: props.editorTheme,
            isHidden: activeSecondaryEditor !== "headers",
            keyMap: props.keyMap,
            onEdit: props.onEditHeaders,
            readOnly: props.readOnly
          }
        )
      ))
    )),
    /* @__PURE__ */ React.createElement(
      "div",
      {
        className: "graphiql-horizontal-drag-bar",
        ref: editorResize.dragBarRef
      }
    ),
    /* @__PURE__ */ React.createElement("div", { ref: editorResize.secondRef }, /* @__PURE__ */ React.createElement("div", { className: "graphiql-response" }, executionContext.isFetching ? /* @__PURE__ */ React.createElement(react.Spinner, null) : null, /* @__PURE__ */ React.createElement(
      react.ResponseEditor,
      {
        editorTheme: props.editorTheme,
        responseTooltip: props.responseTooltip,
        keyMap: props.keyMap
      }
    ), footer))
  ))), /* @__PURE__ */ React.createElement(
    react.Dialog,
    {
      open: showDialog === "short-keys",
      onOpenChange: handleOpenShortKeysDialog
    },
    /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-header" }, /* @__PURE__ */ React.createElement(react.Dialog.Title, { className: "graphiql-dialog-title" }, "Short Keys"), /* @__PURE__ */ React.createElement(react.Dialog.Close, null)),
    /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-section" }, /* @__PURE__ */ React.createElement(ShortKeys, { keyMap: props.keyMap || "sublime" }))
  ), /* @__PURE__ */ React.createElement(
    react.Dialog,
    {
      open: showDialog === "settings",
      onOpenChange: handleOpenSettingsDialog
    },
    /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-header" }, /* @__PURE__ */ React.createElement(react.Dialog.Title, { className: "graphiql-dialog-title" }, "Settings"), /* @__PURE__ */ React.createElement(react.Dialog.Close, null)),
    props.showPersistHeadersSettings ? /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-section" }, /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-section-title" }, "Persist headers"), /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-section-caption" }, "Save headers upon reloading.", " ", /* @__PURE__ */ React.createElement("span", { className: "graphiql-warning-text" }, "Only enable if you trust this device."))), /* @__PURE__ */ React.createElement(react.ButtonGroup, null, /* @__PURE__ */ React.createElement(
      react.Button,
      {
        type: "button",
        id: "enable-persist-headers",
        className: editorContext.shouldPersistHeaders ? "active" : "",
        "data-value": "true",
        onClick: handlePersistHeaders
      },
      "On"
    ), /* @__PURE__ */ React.createElement(
      react.Button,
      {
        type: "button",
        id: "disable-persist-headers",
        className: editorContext.shouldPersistHeaders ? "" : "active",
        onClick: handlePersistHeaders
      },
      "Off"
    ))) : null,
    !forcedTheme && /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-section" }, /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-section-title" }, "Theme"), /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-section-caption" }, "Adjust how the interface appears.")), /* @__PURE__ */ React.createElement(react.ButtonGroup, null, /* @__PURE__ */ React.createElement(
      react.Button,
      {
        type: "button",
        className: theme === null ? "active" : "",
        onClick: handleChangeTheme
      },
      "System"
    ), /* @__PURE__ */ React.createElement(
      react.Button,
      {
        type: "button",
        className: theme === "light" ? "active" : "",
        "data-theme": "light",
        onClick: handleChangeTheme
      },
      "Light"
    ), /* @__PURE__ */ React.createElement(
      react.Button,
      {
        type: "button",
        className: theme === "dark" ? "active" : "",
        "data-theme": "dark",
        onClick: handleChangeTheme
      },
      "Dark"
    ))),
    storageContext ? /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-section" }, /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-section-title" }, "Clear storage"), /* @__PURE__ */ React.createElement("div", { className: "graphiql-dialog-section-caption" }, "Remove all locally stored data and start fresh.")), /* @__PURE__ */ React.createElement(
      react.Button,
      {
        type: "button",
        state: clearStorageStatus || void 0,
        disabled: clearStorageStatus === "success",
        onClick: handleClearData
      },
      {
        success: "Cleared data",
        error: "Failed"
      }[clearStorageStatus] || "Clear data"
    )) : null
  )));
}
const modifier = typeof window !== "undefined" && window.navigator.platform.toLowerCase().indexOf("mac") === 0 ? "Cmd" : "Ctrl";
const SHORT_KEYS = Object.entries({
  "Search in editor": [modifier, "F"],
  "Search in documentation": [modifier, "K"],
  "Execute query": [modifier, "Enter"],
  "Prettify editors": ["Ctrl", "Shift", "P"],
  "Merge fragments definitions into operation definition": [
    "Ctrl",
    "Shift",
    "M"
  ],
  "Copy query": ["Ctrl", "Shift", "C"],
  "Re-fetch schema using introspection": ["Ctrl", "Shift", "R"]
});
function ShortKeys({ keyMap }) {
  return /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement("table", { className: "graphiql-table" }, /* @__PURE__ */ React.createElement("thead", null, /* @__PURE__ */ React.createElement("tr", null, /* @__PURE__ */ React.createElement("th", null, "Short Key"), /* @__PURE__ */ React.createElement("th", null, "Function"))), /* @__PURE__ */ React.createElement("tbody", null, SHORT_KEYS.map(([title, keys]) => /* @__PURE__ */ React.createElement("tr", { key: title }, /* @__PURE__ */ React.createElement("td", null, keys.map((key, index, array) => /* @__PURE__ */ React.createElement(React.Fragment, { key }, /* @__PURE__ */ React.createElement("code", { className: "graphiql-key" }, key), index !== array.length - 1 && " + "))), /* @__PURE__ */ React.createElement("td", null, title))))), /* @__PURE__ */ React.createElement("p", null, "The editors use", " ", /* @__PURE__ */ React.createElement(
    "a",
    {
      href: "https://codemirror.net/5/doc/manual.html#keymaps",
      target: "_blank",
      rel: "noopener noreferrer"
    },
    "CodeMirror Key Maps"
  ), " ", "that add more short keys. This instance of Graph", /* @__PURE__ */ React.createElement("em", null, "i"), "QL uses", " ", /* @__PURE__ */ React.createElement("code", null, keyMap), "."));
}
function GraphiQLLogo(props) {
  return /* @__PURE__ */ React.createElement("div", { className: "graphiql-logo" }, props.children || /* @__PURE__ */ React.createElement(
    "a",
    {
      className: "graphiql-logo-link",
      href: "https://github.com/graphql/graphiql",
      target: "_blank",
      rel: "noreferrer"
    },
    "Graph",
    /* @__PURE__ */ React.createElement("em", null, "i"),
    "QL"
  ));
}
GraphiQLLogo.displayName = "GraphiQLLogo";
function GraphiQLToolbar(props) {
  return /* @__PURE__ */ React.createElement(React.Fragment, null, props.children);
}
GraphiQLToolbar.displayName = "GraphiQLToolbar";
function GraphiQLFooter(props) {
  return /* @__PURE__ */ React.createElement("div", { className: "graphiql-footer" }, props.children);
}
GraphiQLFooter.displayName = "GraphiQLFooter";
function isChildComponentType(child, component) {
  var _a;
  if (((_a = child == null ? void 0 : child.type) == null ? void 0 : _a.displayName) && child.type.displayName === component.displayName) {
    return true;
  }
  return child.type === component;
}
Object.defineProperty(exports, "GraphiQLProvider", {
  enumerable: true,
  get: () => react.GraphiQLProvider
});
exports.GraphiQL = GraphiQL;
exports.GraphiQLInterface = GraphiQLInterface;
exports.default = GraphiQL;
//# sourceMappingURL=index.js.map
